function [choix, ColNo, paraName, nPara] = choixparametres( fid, DELIMITER )
% 
% Cette fonction permet a l'utilisateur de choisir les parametres presents
% dans le fichier et qui seront utilises par le programme.
% Le choix se fait sur les parametres suivants :
%              date, heure, lat, lon
% La fonction retournera systematiquement les parametres suivants
%                cond, hcond, sog, cog
%
% [ColNo, nPara] = choixparametres( fid, DELIMITER );
%
% Input
%   fid ........... Numero logique du fichier a decoder
%   DELIMITER ..... caractere separant chaque parametre a decoder sur
%                   une ligne
%
% output
%   choix ......... String 'yes' ou 'cancel' qui indique si le programme
%                   doit s'arreter
%   ColNo ......... Structure donnant pour chaque parametre le numero de
%                   la colonne a lire
%   paraName ...... Intitule des parametres de la ligne d'entete 
%   nPara ......... Nombre de parametre total present dans le fichier
%
% ------------------------------------------------------------------------

% Initialisation des indices de colonne que l'on conserve systematiquement
% -------------------------------------------------------------------------
dateNo = 0; timeNo = 0; tempNo = 0; salNo = 0; condNo = 0; rawNo = 0;
latNo = 0; lonNo = 0; sogNo = 0; cogNo = 0;

% Lecture de la 1ere ligne
%
% ATTENTION : Je considere que cette ligne est la ligne d'entete
% IL FAUDRAIT FAIRE UN TEST POUR VERIFIER QUE C'EST BIEN  UNE LIGNE
% D'ENTETE
% --------------------------------------------------------------
firstLine = fgets( fid );
    
% Decode la ligne d'entete et place l'intitule de chaque colonne
% dans une variable de type 'cell' : paraName avec nPara elements
% -------------------------------------------------------------------
[paraName, nPara] = decodestr( firstLine, DELIMITER );

% Convertit les intitules de chaque colonne en caracteres minuscules
% ------------------------------------------------------------------
paraName = lower(paraName);

% Vector of indices of the list box items that are initially selected.
% --------------------------------------------------------------------
ind = 0;
for ipar = 1 : nPara
  header = char( paraName(1, ipar) );
  if ~isempty(strfind( header, 'date')) && dateNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    dateNo = ipar;
  elseif ~isempty(strfind( header, 'time')) && timeNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    timeNo = ipar;
  elseif ~isempty(strfind( header, 'temp')) && tempNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    tempNo = ipar;
  elseif ~isempty(strfind( header, 'sal')) && salNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    salNo = ipar;
  elseif ~isempty(strfind( header, 'cond')) && condNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    condNo = ipar;
  elseif ~isempty(strfind( header, 'raw')) && rawNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    rawNo = ipar;
  elseif ~isempty(strfind( header, 'lat')) && latNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    latNo = ipar;
  elseif ~isempty(strfind( header, 'lon')) && lonNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    lonNo = ipar;
  elseif ~isempty(strfind( header, 'sog')) && sogNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    sogNo = ipar;
  elseif ~isempty(strfind( header, 'cog')) && cogNo == 0
    ind = ind + 1;
    defAnsB(ind) = ipar;
    cogNo = ipar;
  end
end

% Tant que 'choix' est egal  'yes' on propose a l'utilisateur
% de faire le choix des entetes. Si le choix est fait, 'choix' est 
% positionne a 'ok'
% ------------------------------------------------------------
choix = 'yes';
while strcmp( choix, 'yes' )
  
  % Affichage d'une 'boite a liste' pour le choix des parametres
  % ------------------------------------------------------------
  [colParaNo, okCol] = listdlg('PromptString', 'Choix des paramtres',...
                       'ListString', paraName, 'InitialValue', defAnsB);

  if okCol == 1
    
    % Le choix s'est bien passe
    % -------------------------
    choix = 'ok';
    
    % Initialisation de la structure indiquant le numero de colonnes des parametres
    % presents dans le fichier intial et qui seront utilises dans TSG-QC
    % --------------------------------------------------------------
    ColNo = struct( 'Date', 0, 'Time', 0, 'Lat', 0, 'Lon', 0, 'Temp', 0,...
                    'Sal', 0, 'Cond', 0, 'Raw', 0, 'Sog', 0, 'Cog', 0);
    
    % Boucle sur les numeros de colonnes des parametres qui seront conserves
    % ----------------------------------------------------------------------
    if ~isempty(okCol)
      for icol = 1 : length(colParaNo)
  
        % Le programme conserve systematiquement la conductivite et les valeurs brutes
        % -----------------------------------------------------------------------------
        if rawNo ~= 0
          i = find( colParaNo == rawNo );
          if isempty(i)
             colParaNo = [colParaNo rawNo];
          end
        end
        if condNo ~= 0
          i = find( colParaNo == condNo );
          if isempty(i)
            colParaNo = [colParaNo condNo];
          end
        end
  
        % Convertion en caracteres
        % ------------------------
        header = char( paraName(1, colParaNo(icol)) );

        % Place les numeros des colonnes dans la structure
        % ------------------------------------------------
        if strfind( header, 'date') ~= 0
          ColNo.Date = colParaNo(icol);
        elseif strfind( header, 'time') ~= 0
          ColNo.Time = colParaNo(icol);
        elseif strfind( header, 'lat') ~= 0
          ColNo.Lat = colParaNo(icol);
        elseif strfind( header, 'lon') ~= 0
          ColNo.Lon = colParaNo(icol);
        elseif strfind( header, 'temp') ~= 0
          ColNo.Temp = colParaNo(icol);
        elseif strfind( header, 'sal') ~= 0
          ColNo.Sal = colParaNo(icol);
        elseif strfind( header, 'cond') ~= 0
          ColNo.Cond = colParaNo(icol);
        elseif strfind( header, 'raw') ~= 0
          ColNo.Raw = colParaNo(icol);
        elseif strfind( header, 'sog') ~= 0
          ColNo.Sog = colParaNo(icol);
        elseif strfind( header, 'cog') ~= 0
          ColNo.Cog = colParaNo(icol);
        end
      end
      % ******************
      clear defAnsB
      defAnsB = colParaNo;
      clear colParaNo
      % ******************
    end

    % Gestion d'erreur
    % ----------------
    if ColNo.Date == 0
      choix = questdlg('Vous devez choisir une Date !!!',...
        'Aucune date choisie', 'yes', 'cancel', 'yes');
    elseif ColNo.Time == 0
      choix = questdlg('Vous devez choisir une Heure !!!',...
        'Aucune heure choisie', 'yes', 'cancel', 'yes');
    elseif ColNo.Lat == 0
      choix = questdlg('Vous devez choisir une Latitude !!!',...
        'Aucune latitude choisie', 'yes', 'cancel', 'yes');
    elseif ColNo.Lon == 0
      choix = questdlg('Vous devez choisir une Longitude !!!',...
        'Aucune longitude choisie', 'yes', 'cancel', 'yes');
    end
    
  else
    
    % On annulle le choix des parametres. Le programme se termine
    % -----------------------------------------------------------
    choix = 'cancel';
    
  end     % fin de test if okCol == 1
  
end       % Fin de boucle While

% Revient en debut de fichier
% ---------------------------
frewind(fid);