function [error] = readBucketData( hTsgGUI, filename)
% Function to read Bucket data in ASCII format. 
%
% Input
% -----
% hTsgGUI ............ Handel to the main user interface
% filename ........... Data filename
%
% Output
% ------
% error .............. 1: OK - -1 : an error occured
%
% @The data are store using setappdata - Variable name : 'bucketASCII'
%
% Caution : replace the fill-value with NaN
% $Id$

% Open the file
% -------------
fid = fopen( filename, 'r' );

error = -1;
if fid ~= -1

    % Get the tsg structure from application GUI
    % ------------------------------------------
    tsg = getappdata( hTsgGUI, 'tsg_data');
    
    % Read the file - skip 2 lines
    % ----------------------------
    fgetl( fid );
    fgetl( fid );    % Bottle type: OSI - tsg.PSAL_WS_BOTTLE   =  ;
    tsg.PSAL_WS_ANALDATE = fscanf(fid, 'Date of water sample analysis: %s\r\n');
    fgetl( fid );
    
    % Read the data
    % -------------
    bucketData = fscanf(fid,'%d %d %d %d %d %f %f %f %d', [9 Inf])';
    
    % Every variable are put in a structure
    % -------------------------------------
    tsg.DAYD_WS   = datenum(bucketData(:,1), bucketData(:,2), ...
                            bucketData(:,3), bucketData(:,4), ...
                            bucketData(:,5), 0);
                           
    % save original date  
    % ------------------
    tsg.DATE_WS    = deblank( datestr(  tsg.DAYD_WS, 'yyyymmddHHMMSS' ));                     
   
    tsg.LATX_WS    = bucketData(:,6);
    tsg.LONX_WS    = bucketData(:,7);
    tsg.SSPS_WS    = bucketData(:,8);
    
    % QC codes are of type BYTE - conversion
    % --------------------------------------
    tsg.SSPS_WS_QC = int8(bucketData(:,9));
    
    % Sort the struct tsg - increasing time.
    % -----------------------------------------
    if ~isempty(tsg.DAYD_WS)
      [tsg.DAYD_WS, iOrder] = sort(tsg.DAYD_WS);
      tsg.DATE_WS           = tsg.DATE_WS(iOrder,:);
      tsg.LATX_WS           = tsg.LATX_WS(iOrder);
      tsg.LONX_WS           = tsg.LONX_WS(iOrder);
      tsg.SSPS_WS           = tsg.SSPS_WS(iOrder);
      tsg.SSPS_WS_QC        = tsg.SSPS_WS_QC(iOrder);
    end

    % Save the data in the application GUI
    % ------------------------------------
    setappdata( hTsgGUI, 'tsg_data', tsg );
    
    % Clear the Workspace
    % -------------------
    clear bucketData
    
    % Close the file
    % --------------
    fclose( fid );
    
    % Everything OK
    % -------------
    error = 1;
end
